Summary:        Library for accessing USB devices
Name:           libusb1
Version:        1.0.27
Release:        4%{?dist}
License:        LGPL-2.1-or-later
Vendor:         Microsoft Corporation
Distribution:   Azure Linux
URL:            https://libusb.info
Source0:        https://github.com/libusb/libusb/releases/download/v%{version}/libusb-%{version}.tar.bz2
BuildRequires:  doxygen
BuildRequires:  gcc
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  systemd-devel
BuildRequires:  umockdev-devel
# libusbx was removed in F34
Provides:       libusbx = %{version}-%{release}

%description
This package provides a way for applications to access USB devices.

libusb is a library for USB device access from Linux, macOS,
Windows, OpenBSD/NetBSD, Haiku and Solaris userspace.

libusb is abstracted internally in such a way that it can hopefully
be ported to other operating systems.

%package        devel
Summary:        Development files for %{name}
License:        LGPL-2.1-or-later
Requires:       %{name}%{?_isa} = %{version}-%{release}
Provides:       libusbx-devel = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package devel-doc
Summary:        Development files for %{name}
License:        LGPL-2.1-or-later
Requires:       libusb1-devel = %{version}-%{release}
Provides:       libusbx-devel-doc = %{version}-%{release}
BuildArch:      noarch

%description devel-doc
This package contains API documentation for %{name}.

%package        tests-examples
Summary:        Tests and examples for %{name}
# The fxload example is GPLv2+, the rest is LGPLv2+, like libusb itself.
License:        LGPLv2+ AND GPLv2+
Requires:       %{name}%{?_isa} = %{version}-%{release}
Provides:       libusbx-tests-examples = %{version}-%{release}

%description tests-examples
This package contains tests and examples for %{name}.

%prep
%autosetup -p1 -n libusb-%{version}
chmod -x examples/*.c
mkdir -p m4
sed -i '/AM_LDFLAGS = -static/d' tests/Makefile.am


%build
%configure --disable-static --enable-examples-build
%make_build
pushd doc
make docs
popd
pushd tests
make
popd


%install
%make_install
mkdir -p %{buildroot}%{_bindir}
install -m 755 tests/.libs/init_context %{buildroot}%{_bindir}/libusb-test-init_context
install -m 755 tests/.libs/set_option %{buildroot}%{_bindir}/libusb-test-set_option
install -m 755 tests/.libs/stress %{buildroot}%{_bindir}/libusb-test-stress
install -m 755 tests/.libs/stress_mt %{buildroot}%{_bindir}/libusb-test-stress_mt
install -m 755 tests/.libs/umockdev %{buildroot}%{_bindir}/libusb-test-umockdev
install -m 755 examples/.libs/testlibusb \
    %{buildroot}%{_bindir}/libusb-test-libusb
# Some examples are very device-specific / require specific hw and miss --help
# So we only install a subset of more generic / useful examples
for i in fxload listdevs xusb; do
    install -m 755 examples/.libs/$i \
        %{buildroot}%{_bindir}/libusb-example-$i
done
find %{buildroot} -type f -name "*.la" -delete -print


%check
LD_LIBRARY_PATH=libusb/.libs ldd %{buildroot}%{_bindir}/libusb-test-stress
LD_LIBRARY_PATH=libusb/.libs %{buildroot}%{_bindir}/libusb-test-init_context
LD_LIBRARY_PATH=libusb/.libs %{buildroot}%{_bindir}/libusb-test-set_option
LD_LIBRARY_PATH=libusb/.libs %{buildroot}%{_bindir}/libusb-test-stress
LD_LIBRARY_PATH=libusb/.libs %{buildroot}%{_bindir}/libusb-test-umockdev
LD_LIBRARY_PATH=libusb/.libs %{buildroot}%{_bindir}/libusb-test-libusb
LD_LIBRARY_PATH=libusb/.libs %{buildroot}%{_bindir}/libusb-example-listdevs


%ldconfig_scriptlets


%files
%license COPYING
%doc AUTHORS README ChangeLog
%{_libdir}/*.so.*

%files devel
%{_includedir}/libusb-1.0
%{_libdir}/*.so
%{_libdir}/pkgconfig/libusb-1.0.pc

%files devel-doc
%doc doc/api-1.0 examples/*.c

%files tests-examples
%{_bindir}/libusb-example-fxload
%{_bindir}/libusb-example-listdevs
%{_bindir}/libusb-example-xusb
%{_bindir}/libusb-test-init_context
%{_bindir}/libusb-test-set_option
%{_bindir}/libusb-test-stress
%{_bindir}/libusb-test-stress_mt
%{_bindir}/libusb-test-umockdev
%{_bindir}/libusb-test-libusb

%changelog
* Fri Oct 18 2024 Jocelyn Berrendonner <jocelynb@microsoft.com> - 1.0.27-4
- Integrating the spec into Azure Linux
- Initial CBL-Mariner import from Fedora 41 (license: MIT).
- License verified.

## START: Generated by rpmautospec
* Thu Jul 18 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.27-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Wed May 08 2024 Kate Hsuan <hpa@redhat.com> - 1.0.27-2
- Build the test code without a rpath

* Mon Mar 04 2024 Kate Hsuan <hpa@redhat.com> - 1.0.27-1
- Update to 1.0.27
- Update to 1.0.27
- Add tests, including init_context, set_option, and stress_mt

* Thu Jan 25 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.26-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Jan 21 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.26-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Tue Sep 19 2023 Miroslav Suchý <msuchy@redhat.com> - 1.0.26-4
- Migrate to SPDX license

* Thu Jul 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.26-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.26-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Fri Sep 30 2022 Kate Hsuan <hpa@redhat.com> 1.0.26-1
- Update to 1.0.26 

* Wed Feb 02 2022 Benjamin Berg <bberg@redhat.com> 1.0.25-1
- Update to 1.0.25

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.24-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.24-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Tue Jan 19 18:47:55 CET 2021 Benjamin Berg <bberg@redhat.com> - 1.0.24-3
- New libusb1 package replacing libusbx
  Resolves: #1918269
## END: Generated by rpmautospec
